# -*- coding: utf-8 -*-

import pipeline
from pipeline.signals import (
  css_compressed,
  js_compressed,
)


del pipeline

INSTALLED_APPS.append('pipeline')

STATICFILES_STORAGE = (
  'pipeline.storage.PipelineStorage'
)

try:
  STATICFILES_FINDERS
except NameError:
  from django.conf.global_settings import (
    STATICFILES_FINDERS
  )
STATICFILES_FINDERS.append(
  'pipeline.finders.PipelineFinder'
)

PIPELINE = {
  'JAVASCRIPT': {},
  'STYLESHEETS': {},

  'CSS_COMPRESSOR': 'pipeline.compressors.csshtmljsminify.CssHtmlJsMinifyCompressor',
  'JS_COMPRESSOR': 'pipeline.compressors.csshtmljsminify.CssHtmlJsMinifyCompressor',
}

try:
  PIPELINE['PIPELINE_ENABLED'] = CONFIG(
    'PIPELINE_ENABLED',
    cast=bool,
  )
except UndefinedValueError:
  pass


# Poista JS- ja CSS-lähdekoodi paketoinnin jälkeen.
def poista_lahdekoodi(sender, *, package, **kwargs):
  if PIPELINE.get('PIPELINE_ENABLED'):
    for lahde in package.sources:
      sender.compressor.storage.delete(lahde)
css_compressed.connect(poista_lahdekoodi)
js_compressed.connect(poista_lahdekoodi)

del css_compressed
del js_compressed



# -*- coding: utf-8 -*-

import os

from django.core.wsgi import get_wsgi_application

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "protoni.palvelin")

# pylint: disable=invalid-name
application = get_wsgi_application()



# -*- coding: utf-8 -*-

from .asetukset import *


SECRET_KEY = CONFIG('SECRET_KEY', default='subatominen-hiukkanen')

ALLOWED_HOSTS = CONFIG(
  'ALLOWED_HOSTS',
  cast=lambda x: list(map(str.strip, x.split(','))),
)

DEBUG = CONFIG("DEBUG", cast=bool, default=False)

SECURE_CONTENT_TYPE_NOSNIFF = True # per security.W006
SECURE_BROWSER_XSS_FILTER = True # per security.W007
SECURE_SSL_REDIRECT = True # per security.W008
SESSION_COOKIE_SECURE = True # per security.W012
CSRF_COOKIE_SECURE = True # per security.W016
X_FRAME_OPTIONS = 'Deny' # per security.W019

# Ks. Django SSL/HTTPS
# Huom. otsake `X-Forwarded-Proto` asetettava proxy-palvelimella!
SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')

EMAIL_BACKEND = CONFIG('EMAIL_BACKEND', default=(
  'django.core.mail.backends.smtp.EmailBackend'
))
EMAIL_FILE_PATH = CONFIG('EMAIL_FILE_PATH', default=(
  os.path.join(BASE_DIR, 'sahkoposti')
))
EMAIL_HOST = CONFIG('EMAIL_HOST', default='localhost')
EMAIL_PORT = CONFIG('EMAIL_PORT', default=25, cast=int)

# Käytetään tiivistettä staattisten tiedostojen nimissä,
# mikäli asetus on vakioarvossa.
try:
  STATICFILES_STORAGE
except NameError:
  STATICFILES_STORAGE = (
    'django.contrib.staticfiles.storage.ManifestStaticFilesStorage'
  )

# Salasanavaatimukset.
AUTH_PASSWORD_VALIDATORS = [
  {'NAME': (
    'django.contrib.auth.password_validation.UserAttributeSimilarityValidator'
  )},
  {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator'},
  {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator'},
  {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator'},
]



#!/usr/bin/env python

import os
import sys


def main():
  # pylint: disable=not-an-iterable
  os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'protoni.palvelin')
  try:
    import django
  except ImportError as exc:
    raise ImportError(
      "Couldn't import Django. Are you sure it's installed and "
      "available on your PYTHONPATH environment variable? Did you "
      "forget to activate a virtual environment?"
    ) from exc

  django.setup()
  from django.core.management.commands.runserver import Command
  Command.default_addr, Command.default_port = getattr(
    django.conf.settings,
    'RUNSERVER',
    ('127.0.0.1', 8000)
  )
  Command.oletus_ssl_keyfile = getattr(
    django.conf.settings,
    'RUNSERVER_SSL_KEYFILE',
    None
  )
  Command.oletus_ssl_certfile = getattr(
    django.conf.settings,
    'RUNSERVER_SSL_CERTFILE',
    None
  )
  from django.core.management import execute_from_command_line
  execute_from_command_line(sys.argv)


if __name__ == '__main__':
  main()



# -*- coding: utf-8 -*-

from django.conf import settings
from django import forms
from django.shortcuts import redirect
from django.urls import include, path


if 'django.contrib.auth' in settings.INSTALLED_APPS:
  from django.contrib.auth.views import LoginView, LogoutView
  class Sisaankirjautumislomake(LoginView.form_class):
    tallenna_istunto = forms.BooleanField(required=False)
  class Sisaankirjautumisnakyma(LoginView):
    form_class = Sisaankirjautumislomake
    def get_template_names(self):
      return (
        'kirjaudu-sisaan.html',
        'admin/login.html',  # django.contrib.admin
      )
    def form_invalid(self, form):
      if referer := self.request.headers.get('Referer'):
        return redirect(referer)
      return super().form_invalid(form)
      # def form_invalid
    def form_valid(self, form):
      paluu = super().form_valid(form)
      if not form.cleaned_data.get('tallenna_istunto', False):
        self.request.session.set_expiry(0)
      return paluu
      # def form_valid
    # class Sisaankirjautumisnakyma
  class Kirjautuminen:
    urlpatterns = [
      path(
        'sisaan/',
        Sisaankirjautumisnakyma.as_view(),
        name='kirjaudu-sisaan',
      ),
      path('ulos/', LogoutView.as_view(), name='kirjaudu-ulos'),
    ]
    # class Kirjautuminen
  # if 'django.contrib.auth' in settings.INSTALLED_APPS


if 'django.contrib.admin' in settings.INSTALLED_APPS:
  from django.contrib import admin
  class Kanta:
    urlpatterns = [path('', admin.site.urls)]


if 'debug_toolbar' in settings.INSTALLED_APPS:
  class DebugToolbar:
    # Käännetään debug_toolbar-paketin osoitteisto 'djdt`-nimiavaruuteen.
    osoitteet = include('debug_toolbar.urls', namespace='')
    app_name = 'djdt'
    urlpatterns = [
      path('', (osoitteet[0], None, None)),
    ]



# -*- coding: utf-8 -*-

__jalkeen__ = ('whitenoise', )

import corsheaders
del corsheaders

INSTALLED_APPS.append('corsheaders')

for i, valike in enumerate(MIDDLEWARE):
  if valike in (
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'whitenoise.middleware.WhiteNoiseMiddleware',
  ):
    break
else:
  i = len(MIDDLEWARE)
MIDDLEWARE.insert(i, 'corsheaders.middleware.CorsMiddleware')



# -* - coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
  setup_requires='git-versiointi>=1.6rc3',
  name='django-protoni',
  packages=find_packages(),
  py_modules=['manage'],
  include_package_data=True,
  scripts=['manage.py'],
  install_requires=['Django', 'python-decouple-multi'],
  entry_points={
    'django.nakymat': [
      '__debug__ = protoni.nakymat:DebugToolbar',
      'kirjaudu = protoni.nakymat:Kirjautuminen',
      'kanta = protoni.nakymat:Kanta',
    ],
    'django.asetukset': [
      'celery = protoni.laajennos.celery',
      'corsheaders = protoni.laajennos.corsheaders',
      'debug_toolbar = protoni.laajennos.debug_toolbar',
      'dj_database_url = protoni.laajennos.dj_database_url',
      'extensions = protoni.laajennos.extensions',
      'heroku = protoni.laajennos.heroku',
      'hosts = protoni.laajennos.hosts',
      'pipeline = protoni.laajennos.pipeline',
      'sentry = protoni.laajennos.sentry',
      'whitenoise = protoni.laajennos.whitenoise',
    ],
  },
)
